aboutsummaryrefslogtreecommitdiff
path: root/guilib/GUIWindow.h
diff options
context:
space:
mode:
authorjmarshallnz <jmarshallnz@svn>2010-01-09 02:12:30 +0000
committerjmarshallnz <jmarshallnz@svn>2010-01-09 02:12:30 +0000
commitcd1ff654231dd3016703b22d05c1ffc76d4c655c (patch)
treeea244cebb53fc827b01b13acc5000f9fd6434a3a /guilib/GUIWindow.h
parent2e370e36232d786c71a86802ef64c301b977b940 (diff)
changed: CGUIWindow::GetOrigin() -> CGUIControlGroup::GetPosition() with override for window <origin> tags. Fixes possible mouse pointer location issues with dialogs using multiple <origin>'s, and provides consistency when reading these coords at the window level
git-svn-id: https://xbmc.svn.sourceforge.net/svnroot/xbmc/trunk@26566 568bbfeb-2a22-0410-94d2-cc84cf5bfa90
Diffstat (limited to 'guilib/GUIWindow.h')
-rw-r--r--guilib/GUIWindow.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/guilib/GUIWindow.h b/guilib/GUIWindow.h
index 512e844609..8b84d2a106 100644
--- a/guilib/GUIWindow.h
+++ b/guilib/GUIWindow.h
@@ -216,12 +216,12 @@ protected:
int m_renderOrder; // for render order of dialogs
- /*! \brief Grabs the window's origin in skin coordinates
- The windows origin may change based on <origin> tag conditions in the skin
+ /*! \brief Grabs the window's top,left position in skin coordinates
+ The window origin may change based on <origin> tag conditions in the skin.
\return the window's origin in skin coordinates
*/
- CPoint GetOrigin();
+ virtual CPoint GetPosition() const;
std::vector<COrigin> m_origins; // positions of dialogs depending on base window
// control states